/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.artifacts.sinfo.common;

import java.util.HashSet;
import java.util.Set;

import org.dive4elements.artifactdatabase.state.ArtifactAndFacet;
import org.dive4elements.artifactdatabase.state.Facet;
import org.dive4elements.artifacts.CallMeta;
import org.dive4elements.river.artifacts.resources.Resources;
import org.dive4elements.river.artifacts.sinfo.flood_duration.InfrastructureFacet;
import org.dive4elements.river.exports.DiagramGenerator;
import org.dive4elements.river.themes.ThemeDocument;

/**
 * Processor to generate a data series for infrastructure height data loaded from the database
 *
 * @author Matthias Schäfer
 *
 */
public class InfrastructureHeightProcessor extends AbstractSInfoProcessor {

    public static final String FACET_INFRASTRUCTURE_HEIGHT = "sinfo_facet_infrastructure_height";

    private static final String I18N_AXIS_LABEL = "chart.longitudinal.section.yaxis.label";

    private static final String I18N_SERIES_NAME_PATTERN = "infrastructure.height.title";

    private static final Set<String> HANDLED_FACET_TYPES = new HashSet<>();

    static {
        HANDLED_FACET_TYPES.add(FACET_INFRASTRUCTURE_HEIGHT);
    }

    public InfrastructureHeightProcessor() {
        super(I18N_AXIS_LABEL, HANDLED_FACET_TYPES);
    }

    @Override
    protected String generateSeries(final DiagramGenerator generator, final ArtifactAndFacet bundle, final ThemeDocument theme, final boolean visible) {

        return buildSeriesForType(generator, bundle, theme, visible, SInfoResultType.infrastructureHeight, null);
    }

    public static Facet createFacet(final CallMeta callMeta, final String seriesName) {
        return new InfrastructureFacet(FACET_INFRASTRUCTURE_HEIGHT, Resources.getMsg(callMeta, I18N_SERIES_NAME_PATTERN, I18N_SERIES_NAME_PATTERN, seriesName),
                I18N_AXIS_LABEL);
    }
}